:orphan:

:py:mod:`icclim._core.generic`
==============================

.. py:module:: icclim._core.generic


Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   functions/index.rst
   generic_templates/index.rst
   indicator/index.rst
